@@ -1,13 +1,14 @@
 package ZooKeeper;
 use ZooKeeper::XS;
 use ZooKeeper::Constants;
-use Carp;
+use ZooKeeper::Transaction;
+use Carp qw(croak);
 use Module::Runtime qw(require_module);
 use Moo;
 use namespace::autoclean;
 use 5.10.1;
 
-our $VERSION = '0.0.21';
+our $VERSION = '0.1.0';
 
 BEGIN {
     if (my $trace_var = $ENV{PERL_ZOOKEEPER_TRACE}) {
@@ -477,6 +478,23 @@ around set_acl => sub {
     return $self->$orig($path, $acl, $extra{version}//-1);
 };
 
+=head2 transaction
+
+Return a ZooKeeper::Transaction for atomically updating multiple nodes.
+See L<ZooKeeper::Transaction> for more details on using transactions.
+
+    my $txn = $zk->transaction
+                 ->delete( '/some-node'    )
+                 ->create( '/another-node' )
+    my ($delete_result, $create_result) = $txn->commit;
+
+=cut
+
+sub transaction {
+    my ($self) = @_;
+    return ZooKeeper::Transaction->new(handle => $self);
+}
+
 =head2 trace
 
 Set the tracing level for the ZooKeeper client. Can also be set using the PERL_ZOOKEEPER_TRACE environmental variable, where PERL_ZOOKEEPER_TRACE=$level=$file traces to $file with debug level $level.
